@@ -1,8 +1,9 @@
 package Data::Sah::Coerce;
 
-our $DATE = '2020-01-03'; # DATE
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-12'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.046'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 use 5.010001;
 use strict;
@@ -37,6 +38,9 @@ sub gen_coercer {
     my %args = @_;
 
     my $rt = $args{return_type} // 'val';
+    # old values still supported but deprecated
+    $rt = 'bool_coerced+val' if $rt eq 'status+val';
+    $rt = 'bool_coerced+str_errmsg+val' if $rt eq 'status+err+val';
 
     my $rules = Data::Sah::CoerceCommon::get_coerce_rules(
         %args,
@@ -63,9 +67,9 @@ sub gen_coercer {
             if ($i == $#{$rules}) {
                 if ($rt eq 'val') {
                     $prev_term = '$data';
-                } elsif ($rt eq 'status+val') {
+                } elsif ($rt eq 'bool_coerced+val') {
                     $prev_term = '[undef, $data]';
-                } else { # status+err+val
+                } else { # bool_coerced+str_errmsg+val
                     $prev_term = '[undef, undef, $data]';
                 }
             } else {
@@ -78,15 +82,15 @@ sub gen_coercer {
                 } else {
                     $expr = "($rule->{expr_match}) ? ($rule->{expr_coerce}) : $prev_term";
                 }
-            } elsif ($rt eq 'status+val') {
+            } elsif ($rt eq 'bool_coerced+val') {
                 if ($rule->{meta}{might_fail}) {
-                    $expr = "do { if ($rule->{expr_match}) { my \$res = $rule->{expr_coerce}; \$res->[0] ? [1,undef] : [1,\$res->[1]] } else { $prev_term } }";
+                    $expr = "do { if ($rule->{expr_match}) { my \$res = $rule->{expr_coerce}; \$res->[0] ? [1,\$res->[1]] : [1,\$res->[1]] } else { $prev_term } }";
                 } else {
                     $expr = "($rule->{expr_match}) ? [1, $rule->{expr_coerce}] : $prev_term";
                 }
-            } else { # status+err+val
+            } else { # bool_coerced+str_errmsg+val
                 if ($rule->{meta}{might_fail}) {
-                    $expr = "do { if ($rule->{expr_match}) { my \$res = $rule->{expr_coerce}; \$res->[0] ? [1, \$res->[0], undef] : [1, undef, \$res->[1]] } else { $prev_term } }";
+                    $expr = "do { if ($rule->{expr_match}) { my \$res = $rule->{expr_coerce}; \$res->[0] ? [1, \$res->[0], \$res->[1]] : [1, undef, \$res->[1]] } else { $prev_term } }";
                 } else {
                     $expr = "($rule->{expr_match}) ? [1, undef, $rule->{expr_coerce}] : $prev_term";
                 }
@@ -100,8 +104,8 @@ sub gen_coercer {
             "    my \$data = shift;\n",
             "    unless (defined \$data) {\n",
             "        ", ($rt eq 'val' ? "return undef;" :
-                             $rt eq 'status+val' ? "return [undef, undef];" :
-                             "return [undef, undef, undef];" # status+err+val
+                             $rt eq 'bool_coerced+val' ? "return [undef, undef];" :
+                             "return [undef, undef, undef];" # bool_coerced+str_errmsg+val
                          ), "\n",
             "    }\n",
             "    $expr;\n",
@@ -110,9 +114,9 @@ sub gen_coercer {
     } else {
         if ($rt eq 'val') {
             $code = 'sub { $_[0] }';
-        } elsif ($rt eq 'status+val') {
+        } elsif ($rt eq 'bool_coerced+val') {
             $code = 'sub { [undef, $_[0]] }';
-        } else {
+        } else { # bool_coerced+str_errmsg+val
             $code = 'sub { [undef, undef, $_[0]] }';
         }
     }
@@ -143,7 +147,7 @@ Data::Sah::Coerce - Coercion rules for Data::Sah
 
 =head1 VERSION
 
-This document describes version 0.046 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2020-01-03.
+This document describes version 0.047 of Data::Sah::Coerce (from Perl distribution Data-Sah-Coerce), released on 2020-02-12.
 
 =head1 SYNOPSIS
 
@@ -212,13 +216,15 @@ Whether coercion might fail, e.g. because of invalid input. If set to 1,
 C<expr_coerce> key that the C<coerce()> routine returns must be an expression
 that returns an array (envelope) of C<< (error_msg, data) >> instead of just
 coerced data. Error message should be a string that is set when coercion fails
-and explains why. Otherwise, if coercion succeeds, the string should be set to
-undefined value.
+and explains why. Otherwise, if coercion succeeds, the error message string
+should be set to undefined value.
 
 An example of a rule like this is coercing from string in the form of
 "YYYY-MM-DD" to a DateTime object. The rule might match any string in the form
 of C<< /\A(\d{4})-(\d{2})-(\d{2})\z/ >> while it might not be a valid date.
 
+This is used for coercion rules that act as a data checker.
+
 =item * prio => int (0-100, default: 50)
 
 This is to regulate the ordering of rules. The higher the number, the lower the
