@@ -1,8 +1,9 @@
 package Data::Sah::Coerce::js::To_date::From_obj::date;
 
-our $DATE = '2020-01-03'; # DATE
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-12'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.046'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 use 5.010001;
 use strict;
@@ -29,7 +30,7 @@ sub coerce {
         "($dt instanceof Date)",
     );
 
-    $res->{expr_coerce} = "isNaN($dt) ? ['Invalid date'] : [null, $dt]";
+    $res->{expr_coerce} = "isNaN($dt) ? ['Invalid date', $dt] : [null, $dt]";
 
     $res;
 }
@@ -49,7 +50,13 @@ Data::Sah::Coerce::js::To_date::From_obj::date - Coerce date from Date object
 
 =head1 VERSION
 
-This document describes version 0.046 of Data::Sah::Coerce::js::To_date::From_obj::date (from Perl distribution Data-Sah-Coerce), released on 2020-01-03.
+This document describes version 0.047 of Data::Sah::Coerce::js::To_date::From_obj::date (from Perl distribution Data-Sah-Coerce), released on 2020-02-12.
+
+=head1 SYNOPSIS
+
+To use in a Sah schema:
+
+ ["date",{"x.perl.coerce_rules"=>["From_obj::date"]}]
 
 =head1 DESCRIPTION
 
