@@ -1,9 +1,9 @@
 package Data::Sah::Coerce::perl::To_float::From_str::percent;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-01-03'; # DATE
+our $DATE = '2020-02-12'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.046'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 use 5.010001;
 use strict;
@@ -48,7 +48,13 @@ Data::Sah::Coerce::perl::To_float::From_str::percent - Coerce float from percent
 
 =head1 VERSION
 
-This document describes version 0.046 of Data::Sah::Coerce::perl::To_float::From_str::percent (from Perl distribution Data-Sah-Coerce), released on 2020-01-03.
+This document describes version 0.047 of Data::Sah::Coerce::perl::To_float::From_str::percent (from Perl distribution Data-Sah-Coerce), released on 2020-02-12.
+
+=head1 SYNOPSIS
+
+To use in a Sah schema:
+
+ ["float",{"x.perl.coerce_rules"=>["From_str::percent"]}]
 
 =head1 DESCRIPTION
 
