@@ -1,8 +1,9 @@
 package Data::Sah::CoerceCommon;
 
-our $DATE = '2020-01-03'; # DATE
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-02-12'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.046'; # VERSION
+our $VERSION = '0.047'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -30,7 +31,7 @@ our %Default_Rules = (
 
 my %common_args = (
     type => {
-        schema => 'str*', # XXX sah::typename
+        schema => 'sah::type_name*',
             req => 1,
         pos => 0,
     },
@@ -76,23 +77,30 @@ _
 my %gen_coercer_args = (
     %common_args,
     return_type => {
-        schema => ['str*', in=>[qw/val status+val status+err+val/]],
+        schema => ['str*', {
+            in => [qw/val bool_coerced+val bool_coerced+str_errmsg+val/],
+            prefilters => [
+                ["Str::replace_map", {map=>{
+                    "status+val"     => "bool_coerced+val",
+                    "status+err+val" => "bool_coerced+str_errmsg+val",
+                }}],
+            ],
+        }],
         default => 'val',
         description => <<'_',
 
 `val` means the coercer will return the input (possibly) coerced or undef if
 coercion fails.
 
-`status+val` means the coercer will return a 2-element array. The first element
-is a bool value set to 1 if coercion has been performed or 0 if otherwise. The
-second element is the (possibly) coerced input (or undef if there is a failure
-during coercion).
-
-`status+err+val` means the coercer will return a 3-element array. The first
+`bool_coerced+val` means the coercer will return a 2-element array. The first
 element is a bool value set to 1 if coercion has been performed or 0 if
-otherwise. The second element is the error message string which will be set if
-there is a failure in coercion. The third element is the (possibly) coerced
-input (or undef if there is a failure during coercion).
+otherwise. The second element is the (possibly) coerced input.
+
+`bool_coerced+str_errmsg+val` means the coercer will return a 3-element array.
+The first element is a bool value set to 1 if coercion has been performed or 0
+if otherwise. The second element is the error message string which will be set
+if there is a failure in coercion (or undef if coercion is successful). The
+third element is the (possibly) coerced input.
 
 _
     },
@@ -231,7 +239,7 @@ Data::Sah::CoerceCommon - Common stuffs for Data::Sah::Coerce and Data::Sah::Coe
 
 =head1 VERSION
 
-This document describes version 0.046 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2020-01-03.
+This document describes version 0.047 of Data::Sah::CoerceCommon (from Perl distribution Data-Sah-Coerce), released on 2020-02-12.
 
 =head1 FUNCTIONS
 
@@ -291,7 +299,8 @@ yours to make, via this setting.
 
 =item * B<data_term>* => I<str>
 
-=item * B<type>* => I<str>
+=item * B<type>* => I<sah::type_name>
+
 
 =back
 
